#
# spec file for package python-structlog
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-structlog
Version:        19.2.0
Release:        bp153.1.17
Summary:        Structured Logging for Python
License:        Apache-2.0 OR MIT
Group:          Development/Languages/Python
URL:            http://www.structlog.org/en/stable/
Source:         https://github.com/hynek/structlog/archive/%{version}.tar.gz
BuildRequires:  %{python_module Twisted}
BuildRequires:  %{python_module coverage}
BuildRequires:  %{python_module freezegun >= 0.2.8}
BuildRequires:  %{python_module pretend}
BuildRequires:  %{python_module pytest >= 3.3.0}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module simplejson}
BuildRequires:  %{python_module six}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-six
BuildArch:      noarch
%if %{python_version_nodots} >= 36
BuildRequires:  python3-rapidjson
%endif
%python_subpackages

%description
structlog makes logging in Python less painful and more powerful by adding
structure to your log entries.

It’s up to you whether you want structlog to take care about the output of your
log entries or whether you prefer to forward them to an existing logging system
like the standard library’s logging module.

%prep
%setup -q -n structlog-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc CHANGE* README*
%license LICENSE*
%{python_sitelib}/*

%changelog
* Thu Oct 17 2019 Michael Vetter <mvetter@suse.com>
- Update to 19.2.0:
  Backward-incompatible changes:
  * Python 3.4 is not supported anymore. It has been unsupported by
    the Python core team for a while now and its PyPI downloads are negligible.
    It's very unlikely that structlog will break under 3.4 anytime soon,
    but we don't test it anymore.
  Changes:
  * Full Python 3.8 support for structlog.stdlib.
  * Added more pass-through properties to structlog.stdlib.BoundLogger.
    To makes it easier to use it as a drop-in replacement for logging.Logger. #198
  * structlog.stdlib.ProcessorFormatter now takes a logger object as an
    optional keyword argument. This makes ProcessorFormatter work properly
    with stuctlog.stdlib.filter_by_level(). #219
  * structlog.dev.ConsoleRenderer now uses no colors by default, if
    colorama is not available. #215
  * structlog.dev.ConsoleRenderer now initializes colorama lazily, to
    prevent accidental side-effects just by importing structlog. #210
  * Added new processor structlog.dev.set_exc_info() that will set
    exc_info=True if the method's name is exception and exc_info isn't
    set at all. This is only necessary when the standard library integration
    is not used. It fixes the problem that in the default configuration,
    structlog.get_logger().exception("hi") in an except block would not print the
    exception without passing exc_info=True to it explicitly. #130, #173, #200, #204
  * A best effort has been made to make as much of structlog pickleable as possible
    to make it friendlier with multiprocessing and similar libraries.
    Some classes can only be pickled on Python 3 or using the dill library
    though and that is very unlikely to change.
  * So far, the configuration proxy, structlog.processor.TimeStamper,
    structlog.BoundLogger, structlog.PrintLogger and structlog.dev.ConsoleRenderer
    have been made pickelable. Please report if you need any another class fixed. #126
  * Added a new thread-local API that allows binding values to a thread-local
    context explicitly without affecting the default behavior of bind(). #222, #225
  * Added pass_foreign_args argument to structlog.stdlib.ProcessorFormatter.
    It allows to pass a foreign log record's args attribute to the event
    dictionary under the positional_args key. #228
  * structlog.dev.ConsoleRenderer now calls str() on the event value. #221
* Tue Apr  2 2019 mvetter@suse.com
- Update to 19.1.0:
  * structlog.ReturnLogger and structlog.PrintLogger now have
    a fatal() log method. #181
  * Under certain (rather unclear) circumstances, the frame
    extraction could throw an SystemError: error return without
    exception set. A workaround has been added. #174
  * structlog now tolerates passing through dicts to stdlib
    logging. #187 #188 #189
- Use pytest macro
* Thu Nov 29 2018 ecsos@opensuse.org
- Fix source address and add missing source.
* Thu Nov 22 2018 Karol Babioch <kbabioch@suse.de>
- Version update to 18.2.0
  * Added structlog.stdlib.add_log_level_number() processor that adds the level
    number to the event dictionary. Can be used to simplify log filtering.
  * structlog.processors.JSONRenderer now allows for overwriting the default
    argument of its serializer.
  * Added try_unbind() that works like unbind() but doesn't raise a KeyError if
    one of the keys is missing. #171
* Tue Jul 31 2018 kbabioch@suse.com
- Initial packaging of version 18.1.0
